![](https://mxstorage.oss-cn-beijing.aliyuncs.com/oss-accesslog/zf-main-logo.png)

# README

## Project description
Zoo Framework is a simple and quick multi-threaded framework.

## Installation
You may install this software from your distribution packages, or through pip:
```
pip install zoo
```

## Configuration
Create a simple object
```
zfc --create simple_object
```

## Other Commands
Create a demo thread
```
zfc --thread demo
```
